package io.trygvis.android;

public final class Optional<T> {
    private final T value;

    public Optional(T value) {
        this.value = value;
    }

    public T get() {
        if (value == null) {
            throw new IllegalStateException("get() on empty");
        }

        return value;
    }

    public boolean isPresent() {
        return value != null;
    }

    public void ifPresent(Consumer<T> consumer) {
        if (value == null) {
            return;
        }

        consumer.accept(value);
    }

    public static <T> Optional<T> of(T t) {
        if (t == null) {
            throw new IllegalArgumentException("t can't be null");
        }

        return new Optional<>(t);
    }

    public static <T> Optional<T> empty() {
        return new Optional<>(null);
    }

    public static <T> Optional<T> ofNullable(T t) {
        return t != null ? of(t) : empty();
    }
}
